

Record
=====================

.. currentmodule:: pyvo.dal.query

.. autoclass:: Record
   :show-inheritance:

   
     
   

   
   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~Record.cachedataset
      ~Record.fielddesc
      ~Record.get_str
      ~Record.getdataset
      ~Record.getdataurl
      ~Record.make_dataset_filename
      ~Record.suggest_dataset_basename
      ~Record.suggest_extension

   
   

   
   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: cachedataset
   .. automethod:: fielddesc
   .. automethod:: get_str
   .. automethod:: getdataset
   .. automethod:: getdataurl
   .. automethod:: make_dataset_filename
   .. automethod:: suggest_dataset_basename
   .. automethod:: suggest_extension

   
   